# -*- coding: utf-8 -*-
info = {
    "name": "nb",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "mars",
        "mar"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "august",
        "aug"
    ],
    "september": [
        "september",
        "sep"
    ],
    "october": [
        "oktober",
        "okt"
    ],
    "november": [
        "november",
        "nov"
    ],
    "december": [
        "desember",
        "des"
    ],
    "monday": [
        "mandag",
        "man"
    ],
    "tuesday": [
        "tirsdag",
        "tir"
    ],
    "wednesday": [
        "onsdag",
        "ons"
    ],
    "thursday": [
        "torsdag",
        "tor"
    ],
    "friday": [
        "fredag",
        "fre"
    ],
    "saturday": [
        "lørdag",
        "lør"
    ],
    "sunday": [
        "søndag",
        "søn"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "år"
    ],
    "month": [
        "måned",
        "mnd",
        "md"
    ],
    "week": [
        "uke",
        "u",
        "uker"
    ],
    "day": [
        "dag",
        "d",
        "dager"
    ],
    "hour": [
        "time",
        "t",
        "timer"
    ],
    "minute": [
        "minutt",
        "min",
        "m"
    ],
    "second": [
        "sekund",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "i fjor"
        ],
        "0 year ago": [
            "i år"
        ],
        "in 1 year": [
            "neste år"
        ],
        "1 month ago": [
            "forrige måned",
            "forrige md"
        ],
        "0 month ago": [
            "denne måneden",
            "denne md"
        ],
        "in 1 month": [
            "neste måned",
            "neste md"
        ],
        "1 week ago": [
            "forrige uke"
        ],
        "0 week ago": [
            "denne uken"
        ],
        "in 1 week": [
            "neste uke"
        ],
        "1 day ago": [
            "i går"
        ],
        "0 day ago": [
            "i dag"
        ],
        "in 1 day": [
            "i morgen"
        ],
        "0 hour ago": [
            "denne timen"
        ],
        "0 minute ago": [
            "dette minuttet"
        ],
        "0 second ago": [
            "nå"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "om (\\d+) år"
        ],
        "\\1 year ago": [
            "for (\\d+) år siden",
            "–(\\d+) år"
        ],
        "in \\1 month": [
            "om (\\d+) måned",
            "om (\\d+) måneder",
            "om (\\d+) md"
        ],
        "\\1 month ago": [
            "for (\\d+) måned siden",
            "for (\\d+) måneder siden",
            "for (\\d+) md siden"
        ],
        "in \\1 week": [
            "om (\\d+) uke",
            "om (\\d+) uker",
            "om (\\d+) u"
        ],
        "\\1 week ago": [
            "for (\\d+) uke siden",
            "for (\\d+) uker siden",
            "for (\\d+) u siden"
        ],
        "in \\1 day": [
            "om (\\d+) døgn",
            "om (\\d+) d"
        ],
        "\\1 day ago": [
            "for (\\d+) døgn siden",
            "for (\\d+) d siden",
            "for (\\d+) dager siden"
        ],
        "in \\1 hour": [
            "om (\\d+) time",
            "om (\\d+) timer",
            "om (\\d+) t"
        ],
        "\\1 hour ago": [
            "for (\\d+) time siden",
            "for (\\d+) timer siden",
            "for (\\d+) t siden"
        ],
        "in \\1 minute": [
            "om (\\d+) minutt",
            "om (\\d+) minutter",
            "om (\\d+) min"
        ],
        "\\1 minute ago": [
            "for (\\d+) minutt siden",
            "for (\\d+) minutter siden",
            "for (\\d+) min siden"
        ],
        "in \\1 second": [
            "om (\\d+) sekund",
            "om (\\d+) sekunder",
            "om (\\d+) sek"
        ],
        "\\1 second ago": [
            "for (\\d+) sekund siden",
            "for (\\d+) sekunder siden",
            "for (\\d+) sek siden"
        ]
    },
    "locale_specific": {
        "nb-SJ": {
            "name": "nb-SJ"
        }
    },
    "ago": [
        "siden"
    ],
    "in": [
        "om"
    ],
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "nd",
    "date_order": "DMY",
    "january": [
        "zibandlela",
        "zib"
    ],
    "february": [
        "nhlolanja",
        "nhlo"
    ],
    "march": [
        "mbimbitho",
        "mbi"
    ],
    "april": [
        "mabasa",
        "mab"
    ],
    "may": [
        "nkwenkwezi",
        "nkw"
    ],
    "june": [
        "nhlangula",
        "nhla"
    ],
    "july": [
        "ntulikazi",
        "ntu"
    ],
    "august": [
        "ncwabakazi",
        "ncw"
    ],
    "september": [
        "mpandula",
        "mpan"
    ],
    "october": [
        "mfumfu",
        "mfu"
    ],
    "november": [
        "lwezi",
        "lwe"
    ],
    "december": [
        "mpalakazi",
        "mpal"
    ],
    "monday": [
        "mvulo",
        "mvu"
    ],
    "tuesday": [
        "sibili",
        "sib"
    ],
    "wednesday": [
        "sithathu",
        "sit"
    ],
    "thursday": [
        "sine",
        "sin"
    ],
    "friday": [
        "sihlanu",
        "sih"
    ],
    "saturday": [
        "mgqibelo",
        "mgq"
    ],
    "sunday": [
        "sonto",
        "son"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "umnyaka"
    ],
    "month": [
        "inyangacale"
    ],
    "week": [
        "iviki"
    ],
    "day": [
        "ilanga"
    ],
    "hour": [
        "ihola"
    ],
    "minute": [
        "umuzuzu"
    ],
    "second": [
        "isekendi"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "izolo"
        ],
        "0 day ago": [
            "lamuhla"
        ],
        "in 1 day": [
            "kusasa"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "it",
    "date_order": "DMY",
    "january": [
        "gennaio",
        "gen"
    ],
    "february": [
        "febbraio",
        "feb"
    ],
    "march": [
        "marzo",
        "mar"
    ],
    "april": [
        "aprile",
        "apr"
    ],
    "may": [
        "maggio",
        "mag"
    ],
    "june": [
        "giugno",
        "giu"
    ],
    "july": [
        "luglio",
        "lug"
    ],
    "august": [
        "agosto",
        "ago"
    ],
    "september": [
        "settembre",
        "set"
    ],
    "october": [
        "ottobre",
        "ott"
    ],
    "november": [
        "novembre",
        "nov"
    ],
    "december": [
        "dicembre",
        "dic"
    ],
    "monday": [
        "lunedì",
        "lun"
    ],
    "tuesday": [
        "martedì",
        "mar"
    ],
    "wednesday": [
        "mercoledì",
        "mer"
    ],
    "thursday": [
        "giovedì",
        "gio"
    ],
    "friday": [
        "venerdì",
        "ven"
    ],
    "saturday": [
        "sabato",
        "sab"
    ],
    "sunday": [
        "domenica",
        "dom"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "anno",
        "anni"
    ],
    "month": [
        "mese",
        "mesi"
    ],
    "week": [
        "settimana",
        "sett",
        "settimane"
    ],
    "day": [
        "giorno",
        "g",
        "giorni"
    ],
    "hour": [
        "ora",
        "h",
        "ore"
    ],
    "minute": [
        "minuto",
        "min",
        "m",
        "minuti"
    ],
    "second": [
        "secondo",
        "sec",
        "s",
        "secondi"
    ],
    "relative-type": {
        "1 year ago": [
            "anno scorso"
        ],
        "0 year ago": [
            "quest'anno"
        ],
        "in 1 year": [
            "anno prossimo"
        ],
        "1 month ago": [
            "mese scorso"
        ],
        "0 month ago": [
            "questo mese"
        ],
        "in 1 month": [
            "mese prossimo"
        ],
        "1 week ago": [
            "settimana scorsa"
        ],
        "0 week ago": [
            "questa settimana"
        ],
        "in 1 week": [
            "settimana prossima"
        ],
        "1 day ago": [
            "ieri"
        ],
        "0 day ago": [
            "oggi"
        ],
        "in 1 day": [
            "domani"
        ],
        "0 hour ago": [
            "quest'ora"
        ],
        "0 minute ago": [
            "questo minuto"
        ],
        "0 second ago": [
            "ora"
        ],
        "2 day ago": [
            "altro ieri"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "tra (\\d+) anno",
            "tra (\\d+) anni"
        ],
        "\\1 year ago": [
            "(\\d+) anno fa",
            "(\\d+) anni fa"
        ],
        "in \\1 month": [
            "tra (\\d+) mese",
            "tra (\\d+) mesi"
        ],
        "\\1 month ago": [
            "(\\d+) mese fa",
            "(\\d+) mesi fa"
        ],
        "in \\1 week": [
            "tra (\\d+) settimana",
            "tra (\\d+) settimane",
            "tra (\\d+) sett"
        ],
        "\\1 week ago": [
            "(\\d+) settimana fa",
            "(\\d+) settimane fa",
            "(\\d+) sett fa"
        ],
        "in \\1 day": [
            "tra (\\d+) giorno",
            "tra (\\d+) giorni",
            "tra (\\d+) g",
            "tra (\\d+) gg"
        ],
        "\\1 day ago": [
            "(\\d+) giorno fa",
            "(\\d+) giorni fa",
            "(\\d+) g fa",
            "(\\d+) gg fa"
        ],
        "in \\1 hour": [
            "tra (\\d+) ora",
            "tra (\\d+) ore",
            "tra (\\d+) h"
        ],
        "\\1 hour ago": [
            "(\\d+) ora fa",
            "(\\d+) ore fa",
            "(\\d+) h fa"
        ],
        "in \\1 minute": [
            "tra (\\d+) minuto",
            "tra (\\d+) minuti",
            "tra (\\d+) min"
        ],
        "\\1 minute ago": [
            "(\\d+) minuto fa",
            "(\\d+) minuti fa",
            "(\\d+) min fa"
        ],
        "in \\1 second": [
            "tra (\\d+) secondo",
            "tra (\\d+) secondi",
            "tra (\\d+) sec",
            "tra (\\d+) s"
        ],
        "\\1 second ago": [
            "(\\d+) secondo fa",
            "(\\d+) secondi fa",
            "(\\d+) sec fa",
            "(\\d+) s fa"
        ]
    },
    "locale_specific": {
        "it-CH": {
            "name": "it-CH"
        },
        "it-SM": {
            "name": "it-SM"
        },
        "it-VA": {
            "name": "it-VA"
        }
    },
    "skip": [
        "circa",
        "e",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "fa"
    ],
    "in": [
        "in"
    ],
    "simplifications": [
        {
            "(\\d+)\\s+ora": "\\1 ore"
        }
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "nus",
    "date_order": "DMY",
    "january": [
        "tiop thar pɛt",
        "tiop"
    ],
    "february": [
        "pɛt"
    ],
    "march": [
        "duɔ̱ɔ̱ŋ",
        "duɔ̱ɔ̱"
    ],
    "april": [
        "guak"
    ],
    "may": [
        "duät",
        "duä"
    ],
    "june": [
        "kornyoot",
        "kor"
    ],
    "july": [
        "pay yie̱tni",
        "pay"
    ],
    "august": [
        "tho̱o̱r",
        "thoo"
    ],
    "september": [
        "tɛɛr",
        "tɛɛ"
    ],
    "october": [
        "laath",
        "laa"
    ],
    "november": [
        "kur"
    ],
    "december": [
        "tio̱p in di̱i̱t",
        "tid"
    ],
    "monday": [
        "jiec la̱t",
        "jiec"
    ],
    "tuesday": [
        "rɛw lätni",
        "rɛw"
    ],
    "wednesday": [
        "diɔ̱k lätni",
        "diɔ̱k"
    ],
    "thursday": [
        "ŋuaan lätni",
        "ŋuaan"
    ],
    "friday": [
        "dhieec lätni",
        "dhieec"
    ],
    "saturday": [
        "bäkɛl lätni",
        "bäkɛl"
    ],
    "sunday": [
        "cäŋ kuɔth",
        "cäŋ"
    ],
    "am": [
        "rw"
    ],
    "pm": [
        "tŋ"
    ],
    "year": [
        "ruɔ̱n"
    ],
    "month": [
        "pay"
    ],
    "week": [
        "jiɔk"
    ],
    "day": [
        "cäŋ"
    ],
    "hour": [
        "thaak"
    ],
    "minute": [
        "minit"
    ],
    "second": [
        "thɛkɛni"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "pan"
        ],
        "0 day ago": [
            "walɛ"
        ],
        "in 1 day": [
            "ruun"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "%%spellout-cardinal-feminine-accusative": {
        "(0, 1)": "ERROR;",
        "2": "dvi;",
        "3": "tris;",
        "4": "keturias;",
        "5": "penkias;",
        "6": "šešias;",
        "7": "septynias;",
        "8": "aštuonias;",
        "9": "devynias;",
        "(10, 'inf')": "ERROR;"
    },
    "%%spellout-thousands": {
        "0": "tūkstančių;",
        "1": "=%spellout-cardinal-masculine= tūkstantis;",
        "(2, 9)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "(10, 20)": "=%spellout-cardinal-masculine= tūkstančių;",
        "21": "=%spellout-cardinal-masculine= tūkstantis;",
        "(22, 29)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "30": "=%spellout-cardinal-masculine= tūkstančių;",
        "31": "=%spellout-cardinal-masculine= tūkstantis;",
        "(32, 39)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "40": "=%spellout-cardinal-masculine= tūkstančių;",
        "41": "=%spellout-cardinal-masculine= tūkstantis;",
        "(42, 49)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "50": "=%spellout-cardinal-masculine= tūkstančių;",
        "51": "=%spellout-cardinal-masculine= tūkstantis;",
        "(52, 59)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "60": "=%spellout-cardinal-masculine= tūkstančių;",
        "61": "=%spellout-cardinal-masculine= tūkstantis;",
        "(62, 69)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "70": "=%spellout-cardinal-masculine= tūkstančių;",
        "71": "=%spellout-cardinal-masculine= tūkstantis;",
        "(72, 79)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "80": "=%spellout-cardinal-masculine= tūkstančių;",
        "81": "=%spellout-cardinal-masculine= tūkstantis;",
        "(82, 89)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "90": "=%spellout-cardinal-masculine= tūkstančių;",
        "91": "=%spellout-cardinal-masculine= tūkstantis;",
        "(92, 99)": "=%spellout-cardinal-masculine= tūkstančiai;",
        "(100, 199)": "šimtas >>;",
        "(200, 'inf')": "<%spellout-cardinal-masculine< šimtai >>;"
    },
    "%spellout-cardinal-feminine": {
        "0": "nulis;",
        "1": "viena;",
        "2": "dvi;",
        "3": "trys;",
        "(4, 9)": "=%spellout-cardinal-masculine=os;",
        "(10, 19)": "=%spellout-cardinal-masculine=;",
        "(20, 99)": "<%%spellout-cardinal-feminine-accusative<dešimt[ >>];",
        "(100, 199)": "šimtas[ >>];",
        "(200, 999)": "<%spellout-cardinal-masculine< šimtai[ >>];",
        "(1000, 999999)": "tūkstantis[ >>];",
        "(1000000, 1999999)": "vienas milijonas[ >>];",
        "(2000000, 999999999)": "<%spellout-cardinal-masculine< milijonų[ >>];",
        "(1000000000, 1999999999)": "vienas milijardas[ >>];",
        "(2000000000, 999999999999)": "<%spellout-cardinal-masculine< milijardų[ >>];",
        "(1000000000000, 1999999999999)": "vienas trilijonas[ >>];",
        "(2000000000000, 999999999999999)": "<%spellout-cardinal-masculine< trilijonų[ >>];",
        "(1000000000000000, 1999999999999999)": "vienas kvadrilijonas[ >>];",
        "(2000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< kvadrilijonų[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-cardinal-masculine": {
        "0": "nulis;",
        "1": "vienas;",
        "2": "du;",
        "3": "trys;",
        "4": "keturi;",
        "5": "penki;",
        "6": "šeši;",
        "7": "septyni;",
        "8": "aštuoni;",
        "9": "devyni;",
        "10": "dešimt;",
        "11": "vienuolika;",
        "12": "dvylika;",
        "13": "trylika;",
        "(14, 19)": ">>olika;",
        "(20, 99)": "<%%spellout-cardinal-feminine-accusative<dešimt[ >>];",
        "(100, 199)": "šimtas[ >>];",
        "(200, 999)": "<%spellout-cardinal-masculine< šimtai[ >>];",
        "(1000, 999999)": "tūkstantis[ >>];",
        "(1000000, 1999999)": "vienas milijonas[ >>];",
        "(2000000, 999999999)": "<%spellout-cardinal-masculine< milijonų[ >>];",
        "(1000000000, 1999999999)": "vienas milijardas[ >>];",
        "(2000000000, 999999999999)": "<%spellout-cardinal-masculine< milijardų[ >>];",
        "(1000000000000, 1999999999999)": "vienas trilijonas[ >>];",
        "(2000000000000, 999999999999999)": "<%spellout-cardinal-masculine<trilijonų[ >>];",
        "(1000000000000000, 1999999999999999)": "vienas kvadrilijonas[ >>];",
        "(2000000000000000, 999999999999999999)": "<%spellout-cardinal-masculine< kvadrilijonų[ >>];",
        "(1000000000000000000, 'inf')": "=#,##0=;"
    },
    "%spellout-numbering": {
        "(0, 'inf')": "=%spellout-cardinal-masculine=;"
    },
    "%spellout-numbering-year": {
        "(0, 'inf')": "=%spellout-numbering=;"
    }
}



# -*- coding: utf-8 -*-
info = {
    "name": "dsb",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan",
        "januara"
    ],
    "february": [
        "februar",
        "feb",
        "februara"
    ],
    "march": [
        "měrc",
        "měr",
        "měrca"
    ],
    "april": [
        "apryl",
        "apr",
        "apryla"
    ],
    "may": [
        "maj",
        "maja"
    ],
    "june": [
        "junij",
        "jun",
        "junija"
    ],
    "july": [
        "julij",
        "jul",
        "julija"
    ],
    "august": [
        "awgust",
        "awg",
        "awgusta"
    ],
    "september": [
        "september",
        "sep",
        "septembra"
    ],
    "october": [
        "oktober",
        "okt",
        "oktobra"
    ],
    "november": [
        "nowember",
        "now",
        "nowembra"
    ],
    "december": [
        "december",
        "dec",
        "decembra"
    ],
    "monday": [
        "pónjeźele",
        "pón"
    ],
    "tuesday": [
        "wałtora",
        "wał"
    ],
    "wednesday": [
        "srjoda",
        "srj"
    ],
    "thursday": [
        "stwórtk",
        "stw"
    ],
    "friday": [
        "pětk",
        "pět"
    ],
    "saturday": [
        "sobota",
        "sob"
    ],
    "sunday": [
        "njeźela",
        "nje"
    ],
    "am": [
        "dopołdnja"
    ],
    "pm": [
        "wótpołdnja"
    ],
    "year": [
        "lěto",
        "l"
    ],
    "month": [
        "mjasec",
        "mjas"
    ],
    "week": [
        "tyźeń",
        "tyź"
    ],
    "day": [
        "źeń",
        "ź"
    ],
    "hour": [
        "góźina",
        "góź",
        "g"
    ],
    "minute": [
        "minuta",
        "min",
        "m"
    ],
    "second": [
        "sekunda",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "łoni"
        ],
        "0 year ago": [
            "lětosa"
        ],
        "in 1 year": [
            "znowa"
        ],
        "1 month ago": [
            "slědny mjasec"
        ],
        "0 month ago": [
            "ten mjasec"
        ],
        "in 1 month": [
            "pśiducy mjasec"
        ],
        "1 week ago": [
            "slědny tyźeń"
        ],
        "0 week ago": [
            "ten tyźeń"
        ],
        "in 1 week": [
            "pśiducy tyźeń"
        ],
        "1 day ago": [
            "cora"
        ],
        "0 day ago": [
            "źinsa"
        ],
        "in 1 day": [
            "witśe"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "za (\\d+) lěto",
            "za (\\d+) lět",
            "za (\\d+) l"
        ],
        "\\1 year ago": [
            "pśed (\\d+) lětom",
            "pśed (\\d+) lětami",
            "pśed (\\d+) l"
        ],
        "in \\1 month": [
            "za (\\d+) mjasec",
            "za (\\d+) mjasecow",
            "za (\\d+) mjas"
        ],
        "\\1 month ago": [
            "pśed (\\d+) mjasecom",
            "pśed (\\d+) mjasecami",
            "pśed (\\d+) mjas"
        ],
        "in \\1 week": [
            "za (\\d+) tyźeń",
            "za (\\d+) tyźenjow",
            "za (\\d+) tyź"
        ],
        "\\1 week ago": [
            "pśed (\\d+) tyźenjom",
            "pśed (\\d+) tyźenjami",
            "pśed (\\d+) tyź"
        ],
        "in \\1 day": [
            "za (\\d+) źeń",
            "za (\\d+) dnjow",
            "za (\\d+) dnj",
            "za (\\d+) ź"
        ],
        "\\1 day ago": [
            "pśed (\\d+) dnjom",
            "pśed (\\d+) dnjami",
            "pśed (\\d+) dnj",
            "pśed (\\d+) d"
        ],
        "in \\1 hour": [
            "za (\\d+) góźinu",
            "za (\\d+) góźin",
            "za (\\d+) góź",
            "za (\\d+) g"
        ],
        "\\1 hour ago": [
            "pśed (\\d+) góźinu",
            "pśed (\\d+) góźinami",
            "pśed (\\d+) góź",
            "pśed (\\d+) g"
        ],
        "in \\1 minute": [
            "za (\\d+) minutu",
            "za (\\d+) minutow",
            "za (\\d+) min",
            "za (\\d+) m"
        ],
        "\\1 minute ago": [
            "pśed (\\d+) minutu",
            "pśed (\\d+) minutami",
            "pśed (\\d+) min",
            "pśed (\\d+) m"
        ],
        "in \\1 second": [
            "za (\\d+) sekundu",
            "za (\\d+) sekundow",
            "za (\\d+) sek",
            "za (\\d+) s"
        ],
        "\\1 second ago": [
            "pśed (\\d+) sekundu",
            "pśed (\\d+) sekundami",
            "pśed (\\d+) sek",
            "pśed (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "gl",
    "date_order": "DMY",
    "january": [
        "xaneiro",
        "xan"
    ],
    "february": [
        "febreiro",
        "feb"
    ],
    "march": [
        "marzo",
        "mar"
    ],
    "april": [
        "abril",
        "abr"
    ],
    "may": [
        "maio"
    ],
    "june": [
        "xuño"
    ],
    "july": [
        "xullo",
        "xul"
    ],
    "august": [
        "agosto",
        "ago"
    ],
    "september": [
        "setembro",
        "set"
    ],
    "october": [
        "outubro",
        "out"
    ],
    "november": [
        "novembro",
        "nov"
    ],
    "december": [
        "decembro",
        "dec"
    ],
    "monday": [
        "luns"
    ],
    "tuesday": [
        "martes",
        "mar"
    ],
    "wednesday": [
        "mércores",
        "mér"
    ],
    "thursday": [
        "xoves",
        "xov"
    ],
    "friday": [
        "venres",
        "ven"
    ],
    "saturday": [
        "sábado",
        "sáb"
    ],
    "sunday": [
        "domingo",
        "dom"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "ano",
        "a"
    ],
    "month": [
        "mes",
        "m"
    ],
    "week": [
        "semana",
        "sem"
    ],
    "day": [
        "día",
        "d"
    ],
    "hour": [
        "hora",
        "h"
    ],
    "minute": [
        "minuto",
        "min"
    ],
    "second": [
        "segundo",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "o ano pasado",
            "ano pasado"
        ],
        "0 year ago": [
            "este ano"
        ],
        "in 1 year": [
            "o próximo ano",
            "seguinte ano"
        ],
        "1 month ago": [
            "o mes pasado",
            "m pasado"
        ],
        "0 month ago": [
            "este mes",
            "este m"
        ],
        "in 1 month": [
            "o próximo mes",
            "m seguinte"
        ],
        "1 week ago": [
            "a semana pasada",
            "sem pasada"
        ],
        "0 week ago": [
            "esta semana",
            "esta sem"
        ],
        "in 1 week": [
            "a próxima semana",
            "sem seguinte"
        ],
        "1 day ago": [
            "onte"
        ],
        "0 day ago": [
            "hoxe"
        ],
        "in 1 day": [
            "mañá"
        ],
        "0 hour ago": [
            "nesta hora"
        ],
        "0 minute ago": [
            "neste minuto"
        ],
        "0 second ago": [
            "agora"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "en (\\d+) ano",
            "en (\\d+) anos",
            "en (\\d+) a"
        ],
        "\\1 year ago": [
            "hai (\\d+) ano",
            "hai (\\d+) anos",
            "hai (\\d+) a"
        ],
        "in \\1 month": [
            "en (\\d+) mes",
            "en (\\d+) meses",
            "en (\\d+) m"
        ],
        "\\1 month ago": [
            "hai (\\d+) mes",
            "hai (\\d+) meses",
            "hai (\\d+) m"
        ],
        "in \\1 week": [
            "en (\\d+) semana",
            "en (\\d+) semanas",
            "en (\\d+) sem"
        ],
        "\\1 week ago": [
            "hai (\\d+) semana",
            "hai (\\d+) semanas",
            "hai (\\d+) sem"
        ],
        "in \\1 day": [
            "en (\\d+) día",
            "en (\\d+) días",
            "en (\\d+) d"
        ],
        "\\1 day ago": [
            "hai (\\d+) día",
            "hai (\\d+) días",
            "hai (\\d+) d"
        ],
        "in \\1 hour": [
            "en (\\d+) hora",
            "en (\\d+) horas",
            "en (\\d+) h"
        ],
        "\\1 hour ago": [
            "hai (\\d+) hora",
            "hai (\\d+) horas",
            "hai (\\d+) h"
        ],
        "in \\1 minute": [
            "en (\\d+) minuto",
            "en (\\d+) minutos",
            "en (\\d+) min"
        ],
        "\\1 minute ago": [
            "hai (\\d+) minuto",
            "hai (\\d+) minutos",
            "hai (\\d+) min"
        ],
        "in \\1 second": [
            "en (\\d+) segundo",
            "en (\\d+) segundos",
            "en (\\d+) s"
        ],
        "\\1 second ago": [
            "hai (\\d+) segundo",
            "hai (\\d+) segundos",
            "hai (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "ksh",
    "date_order": "DMY",
    "january": [
        "jannewa",
        "jan"
    ],
    "february": [
        "fäbrowa",
        "fäb"
    ],
    "march": [
        "määz",
        "mäz"
    ],
    "april": [
        "aprell",
        "apr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juuni",
        "jun"
    ],
    "july": [
        "juuli",
        "jul"
    ],
    "august": [
        "oujoß",
        "ouj"
    ],
    "september": [
        "septämber",
        "säp"
    ],
    "october": [
        "oktohber",
        "okt"
    ],
    "november": [
        "novämber",
        "nov"
    ],
    "december": [
        "dezämber",
        "dez"
    ],
    "monday": [
        "mohndaach",
        "mo"
    ],
    "tuesday": [
        "dinnsdaach",
        "di"
    ],
    "wednesday": [
        "metwoch",
        "me"
    ],
    "thursday": [
        "dunnersdaach",
        "du"
    ],
    "friday": [
        "friidaach",
        "fr"
    ],
    "saturday": [
        "samsdaach",
        "sa"
    ],
    "sunday": [
        "sunndaach",
        "su"
    ],
    "am": [
        "vörmeddaach",
        "vm",
        "uhr vörmiddaachs"
    ],
    "pm": [
        "nommendaach",
        "nm",
        "uhr nommendaachs"
    ],
    "year": [
        "johr",
        "j"
    ],
    "month": [
        "mohnd",
        "m"
    ],
    "week": [
        "woch",
        "w"
    ],
    "day": [
        "daach",
        "d"
    ],
    "hour": [
        "schtund",
        "std",
        "s"
    ],
    "minute": [
        "menutt",
        "min",
        "m"
    ],
    "second": [
        "sekond",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "läz johr"
        ],
        "0 year ago": [
            "diß johr"
        ],
        "in 1 year": [
            "näx johr"
        ],
        "1 month ago": [
            "lätzde mohnd"
        ],
        "0 month ago": [
            "diese mohnd"
        ],
        "in 1 month": [
            "nächste mohnd"
        ],
        "1 week ago": [
            "läz woch"
        ],
        "0 week ago": [
            "di woch"
        ],
        "in 1 week": [
            "nächste woche"
        ],
        "1 day ago": [
            "jestere"
        ],
        "0 day ago": [
            "hück"
        ],
        "in 1 day": [
            "morje"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "en (\\d+) johr",
            "en (\\d+) johre"
        ],
        "\\1 year ago": [
            "vör (\\d+) johr",
            "vör (\\d+) johre"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "bg",
    "date_order": "DMY",
    "january": [
        "януари",
        "яну",
        "ян"
    ],
    "february": [
        "февруари",
        "фев",
        "фв"
    ],
    "march": [
        "март"
    ],
    "april": [
        "април",
        "апр",
        "ап"
    ],
    "may": [
        "май"
    ],
    "june": [
        "юни",
        "юн"
    ],
    "july": [
        "юли",
        "юл"
    ],
    "august": [
        "август",
        "авг"
    ],
    "september": [
        "септември",
        "сеп",
        "септ",
        "септм"
    ],
    "october": [
        "октомври",
        "окт"
    ],
    "november": [
        "ноември",
        "ное"
    ],
    "december": [
        "декември",
        "дек"
    ],
    "monday": [
        "понеделник",
        "пн",
        "пон"
    ],
    "tuesday": [
        "вторник",
        "вт",
        "вто"
    ],
    "wednesday": [
        "сряда",
        "ср",
        "сря"
    ],
    "thursday": [
        "четвъртък",
        "чт"
    ],
    "friday": [
        "петък",
        "пт"
    ],
    "saturday": [
        "събота",
        "сб"
    ],
    "sunday": [
        "неделя",
        "нд"
    ],
    "am": [
        "am",
        "проб"
    ],
    "pm": [
        "pm",
        "слоб"
    ],
    "year": [
        "година",
        "г",
        "год",
        "години"
    ],
    "month": [
        "месец",
        "м",
        "мес",
        "месеци"
    ],
    "week": [
        "седмица",
        "седм",
        "с",
        "сед",
        "седмици"
    ],
    "day": [
        "ден",
        "д",
        "дни",
        "дена"
    ],
    "hour": [
        "час",
        "ч",
        "часа"
    ],
    "minute": [
        "минута",
        "мин",
        "минути"
    ],
    "second": [
        "секунда",
        "с",
        "сек",
        "секунди"
    ],
    "relative-type": {
        "1 year ago": [
            "миналата година",
            "мин г",
            "преди година"
        ],
        "0 year ago": [
            "тази година",
            "т г"
        ],
        "in 1 year": [
            "следващата година",
            "следв г",
            "сл г"
        ],
        "1 month ago": [
            "предходен месец",
            "мин мес",
            "мин м"
        ],
        "0 month ago": [
            "този месец",
            "този мес",
            "т м"
        ],
        "in 1 month": [
            "следващ месец",
            "следв мес",
            "сл м"
        ],
        "1 week ago": [
            "предходната седмица",
            "миналата седмица",
            "мин седм",
            "преди седмица"
        ],
        "0 week ago": [
            "тази седмица",
            "тази седм"
        ],
        "in 1 week": [
            "следващата седмица",
            "следв седм",
            "сл седм"
        ],
        "1 day ago": [
            "вчера",
            "снощи",
            "преди ден"
        ],
        "0 day ago": [
            "днес"
        ],
        "in 1 day": [
            "утре",
            "след ден"
        ],
        "0 hour ago": [
            "в този час"
        ],
        "0 minute ago": [
            "в тази минута"
        ],
        "0 second ago": [
            "сега"
        ],
        "10 year ago": [
            "преди десетилетие"
        ],
        "in 10 year": [
            "след 1 десетилетие"
        ],
        "2 day ago": [
            "онзи ден"
        ],
        "in 2 day": [
            "вдругиден"
        ],
        "1 hour ago": [
            "преди час"
        ],
        "in 1 hour": [
            "след час"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "след (\\d+) година",
            "след (\\d+) години",
            "след (\\d+) г",
            "сл (\\d+) г"
        ],
        "\\1 year ago": [
            "преди (\\d+) година",
            "преди (\\d+) години",
            "преди (\\d+) г",
            "пр (\\d+) г"
        ],
        "in \\1 month": [
            "след (\\d+) месец",
            "след (\\d+) месеца",
            "след (\\d+) м",
            "сл (\\d+) м"
        ],
        "\\1 month ago": [
            "преди (\\d+) месец",
            "преди (\\d+) месеца",
            "преди (\\d+) м",
            "пр (\\d+) м"
        ],
        "in \\1 week": [
            "след (\\d+) седмица",
            "след (\\d+) седмици",
            "след (\\d+) седм",
            "сл (\\d+) седм"
        ],
        "\\1 week ago": [
            "преди (\\d+) седмица",
            "преди (\\d+) седмици",
            "преди (\\d+) седм",
            "пр (\\d+) седм"
        ],
        "in \\1 day": [
            "след (\\d+) ден",
            "след (\\d+) дни",
            "сл (\\d+) д"
        ],
        "\\1 day ago": [
            "преди (\\d+) ден",
            "преди (\\d+) дни",
            "пр (\\d+) д"
        ],
        "in \\1 hour": [
            "след (\\d+) час",
            "след (\\d+) часа",
            "след (\\d+) ч",
            "сл (\\d+) ч"
        ],
        "\\1 hour ago": [
            "преди (\\d+) час",
            "преди (\\d+) часа",
            "преди (\\d+) ч",
            "пр (\\d+) ч"
        ],
        "in \\1 minute": [
            "след (\\d+) минута",
            "след (\\d+) минути",
            "след (\\d+) мин",
            "сл (\\d+) мин"
        ],
        "\\1 minute ago": [
            "преди (\\d+) минута",
            "преди (\\d+) минути",
            "преди (\\d+) мин",
            "пр (\\d+) мин"
        ],
        "in \\1 second": [
            "след (\\d+) секунда",
            "след (\\d+) секунди",
            "след (\\d+) сек",
            "сл (\\d+) сек"
        ],
        "\\1 second ago": [
            "преди (\\d+) секунда",
            "преди (\\d+) секунди",
            "преди (\\d+) сек",
            "пр (\\d+) сек"
        ]
    },
    "locale_specific": {},
    "skip": [
        "на",
        "върху",
        "под",
        "до",
        "от",
        "около",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "преди"
    ],
    "in": [
        "след",
        "после",
        "подир"
    ],
    "simplifications": [
        {
            "един": "1"
        },
        {
            "два": "2"
        },
        {
            "три": "3"
        }
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "bm",
    "date_order": "DMY",
    "january": [
        "zanwuye",
        "zan"
    ],
    "february": [
        "feburuye",
        "feb"
    ],
    "march": [
        "marisi",
        "mar"
    ],
    "april": [
        "awirili",
        "awi"
    ],
    "may": [
        "mɛ"
    ],
    "june": [
        "zuwɛn",
        "zuw"
    ],
    "july": [
        "zuluye",
        "zul"
    ],
    "august": [
        "uti"
    ],
    "september": [
        "sɛtanburu",
        "sɛt"
    ],
    "october": [
        "ɔkutɔburu",
        "ɔku"
    ],
    "november": [
        "nowanburu",
        "now"
    ],
    "december": [
        "desanburu",
        "des"
    ],
    "monday": [
        "ntɛnɛ",
        "ntɛ"
    ],
    "tuesday": [
        "tarata",
        "tar"
    ],
    "wednesday": [
        "araba",
        "ara"
    ],
    "thursday": [
        "alamisa",
        "ala"
    ],
    "friday": [
        "juma",
        "jum"
    ],
    "saturday": [
        "sibiri",
        "sib"
    ],
    "sunday": [
        "kari",
        "kar"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "san"
    ],
    "month": [
        "kalo"
    ],
    "week": [
        "dɔgɔkun"
    ],
    "day": [
        "don"
    ],
    "hour": [
        "lɛrɛ"
    ],
    "minute": [
        "miniti"
    ],
    "second": [
        "sekondi"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "kunu"
        ],
        "0 day ago": [
            "bi"
        ],
        "in 1 day": [
            "sini"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "fr",
    "date_order": "DMY",
    "january": [
        "janvier",
        "janv",
        "jan"
    ],
    "february": [
        "février",
        "févr",
        "fév"
    ],
    "march": [
        "mars"
    ],
    "april": [
        "avril",
        "avr"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "juin",
        "jun"
    ],
    "july": [
        "juillet",
        "juil",
        "jul"
    ],
    "august": [
        "août",
        "aoû"
    ],
    "september": [
        "septembre",
        "sept",
        "sep"
    ],
    "october": [
        "octobre",
        "oct"
    ],
    "november": [
        "novembre",
        "nov"
    ],
    "december": [
        "décembre",
        "déc"
    ],
    "monday": [
        "lundi",
        "lun",
        "lu"
    ],
    "tuesday": [
        "mardi",
        "mar",
        "ma"
    ],
    "wednesday": [
        "mercredi",
        "mer",
        "me"
    ],
    "thursday": [
        "jeudi",
        "jeu",
        "je"
    ],
    "friday": [
        "vendredi",
        "ven",
        "ve"
    ],
    "saturday": [
        "samedi",
        "sam",
        "sa"
    ],
    "sunday": [
        "dimanche",
        "dim",
        "di"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "année",
        "an",
        "a",
        "années",
        "ans"
    ],
    "month": [
        "mois",
        "m"
    ],
    "week": [
        "semaine",
        "sem",
        "semaines"
    ],
    "day": [
        "jour",
        "j",
        "jours"
    ],
    "hour": [
        "heure",
        "h",
        "heures"
    ],
    "minute": [
        "minute",
        "min",
        "minutes"
    ],
    "second": [
        "seconde",
        "s",
        "secondes"
    ],
    "relative-type": {
        "1 year ago": [
            "l'année dernière"
        ],
        "0 year ago": [
            "cette année"
        ],
        "in 1 year": [
            "l'année prochaine"
        ],
        "1 month ago": [
            "le mois dernier"
        ],
        "0 month ago": [
            "ce mois-ci"
        ],
        "in 1 month": [
            "le mois prochain"
        ],
        "1 week ago": [
            "la semaine dernière"
        ],
        "0 week ago": [
            "cette semaine"
        ],
        "in 1 week": [
            "la semaine prochaine"
        ],
        "1 day ago": [
            "hier"
        ],
        "0 day ago": [
            "aujourd'hui"
        ],
        "in 1 day": [
            "demain"
        ],
        "0 hour ago": [
            "cette heure-ci"
        ],
        "0 minute ago": [
            "cette minute-ci"
        ],
        "0 second ago": [
            "maintenant"
        ],
        "2 day ago": [
            "avant-hier"
        ],
        "in 2 day": [
            "après-demain"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "dans (\\d+) an",
            "dans (\\d+) ans",
            "dans (\\d+) a"
        ],
        "\\1 year ago": [
            "il y a (\\d+) an",
            "il y a (\\d+) ans",
            "il y a (\\d+) a"
        ],
        "in \\1 month": [
            "dans (\\d+) mois",
            "dans (\\d+) m"
        ],
        "\\1 month ago": [
            "il y a (\\d+) mois",
            "il y a (\\d+) m"
        ],
        "in \\1 week": [
            "dans (\\d+) semaine",
            "dans (\\d+) semaines",
            "dans (\\d+) sem"
        ],
        "\\1 week ago": [
            "il y a (\\d+) semaine",
            "il y a (\\d+) semaines",
            "il y a (\\d+) sem"
        ],
        "in \\1 day": [
            "dans (\\d+) jour",
            "dans (\\d+) jours",
            "dans (\\d+) j"
        ],
        "\\1 day ago": [
            "il y a (\\d+) jour",
            "il y a (\\d+) jours",
            "il y a (\\d+) j"
        ],
        "in \\1 hour": [
            "dans (\\d+) heure",
            "dans (\\d+) heures",
            "dans (\\d+) h",
            "dans (\\d+)h"
        ],
        "\\1 hour ago": [
            "il y a (\\d+) heure",
            "il y a (\\d+) heures",
            "il y a (\\d+) h",
            "il y a (\\d+)h"
        ],
        "in \\1 minute": [
            "dans (\\d+) minute",
            "dans (\\d+) minutes",
            "dans (\\d+) min"
        ],
        "\\1 minute ago": [
            "il y a (\\d+) minute",
            "il y a (\\d+) minutes",
            "il y a (\\d+) min",
            "il y a (\\d+)min"
        ],
        "in \\1 second": [
            "dans (\\d+) seconde",
            "dans (\\d+) secondes",
            "dans (\\d+) s"
        ],
        "\\1 second ago": [
            "il y a (\\d+) seconde",
            "il y a (\\d+) secondes",
            "il y a (\\d+) s"
        ]
    },
    "locale_specific": {
        "fr-CI": {
            "name": "fr-CI"
        },
        "fr-WF": {
            "name": "fr-WF"
        },
        "fr-BL": {
            "name": "fr-BL"
        },
        "fr-PF": {
            "name": "fr-PF"
        },
        "fr-NC": {
            "name": "fr-NC"
        },
        "fr-MU": {
            "name": "fr-MU"
        },
        "fr-MQ": {
            "name": "fr-MQ"
        },
        "fr-CH": {
            "name": "fr-CH"
        },
        "fr-NE": {
            "name": "fr-NE"
        },
        "fr-BF": {
            "name": "fr-BF"
        },
        "fr-CG": {
            "name": "fr-CG"
        },
        "fr-MA": {
            "name": "fr-MA",
            "january": [
                "jan"
            ],
            "february": [
                "fév"
            ],
            "march": [
                "mar"
            ],
            "june": [
                "jui"
            ]
        },
        "fr-RE": {
            "name": "fr-RE"
        },
        "fr-KM": {
            "name": "fr-KM"
        },
        "fr-BI": {
            "name": "fr-BI"
        },
        "fr-BE": {
            "name": "fr-BE"
        },
        "fr-CA": {
            "name": "fr-CA",
            "date_order": "YMD",
            "july": [
                "juill"
            ]
        },
        "fr-SY": {
            "name": "fr-SY"
        },
        "fr-TD": {
            "name": "fr-TD"
        },
        "fr-CM": {
            "name": "fr-CM",
            "am": [
                "matin",
                "mat"
            ],
            "pm": [
                "soir"
            ]
        },
        "fr-DZ": {
            "name": "fr-DZ"
        },
        "fr-MF": {
            "name": "fr-MF"
        },
        "fr-RW": {
            "name": "fr-RW"
        },
        "fr-MR": {
            "name": "fr-MR"
        },
        "fr-GN": {
            "name": "fr-GN"
        },
        "fr-ML": {
            "name": "fr-ML"
        },
        "fr-VU": {
            "name": "fr-VU"
        },
        "fr-SC": {
            "name": "fr-SC"
        },
        "fr-MG": {
            "name": "fr-MG"
        },
        "fr-SN": {
            "name": "fr-SN"
        },
        "fr-LU": {
            "name": "fr-LU"
        },
        "fr-HT": {
            "name": "fr-HT",
            "day": [
                "jr"
            ],
            "hour": [
                "hr"
            ],
            "second": [
                "sec"
            ]
        },
        "fr-BJ": {
            "name": "fr-BJ"
        },
        "fr-DJ": {
            "name": "fr-DJ"
        },
        "fr-GA": {
            "name": "fr-GA"
        },
        "fr-GQ": {
            "name": "fr-GQ"
        },
        "fr-CF": {
            "name": "fr-CF"
        },
        "fr-TG": {
            "name": "fr-TG"
        },
        "fr-GF": {
            "name": "fr-GF"
        },
        "fr-PM": {
            "name": "fr-PM"
        },
        "fr-YT": {
            "name": "fr-YT"
        },
        "fr-MC": {
            "name": "fr-MC"
        },
        "fr-GP": {
            "name": "fr-GP"
        },
        "fr-TN": {
            "name": "fr-TN"
        },
        "fr-CD": {
            "name": "fr-CD"
        }
    },
    "skip": [
        "le",
        "environ",
        "et",
        "à",
        "er",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "il ya",
        "il y a"
    ],
    "in": [
        "dans",
        "en",
        "après"
    ],
    "simplifications": [
        {
            "d'une": "1"
        },
        {
            "d'un": "1"
        },
        {
            "une": "1"
        },
        {
            "un": "1"
        },
        {
            "(\\d+)\\s+h\\s+(\\d+)\\s+min": "\\1h\\2m"
        },
        {
            "(\\d+)h(\\d+)m?": "\\1:\\2"
        },
        {
            "moins\\s(?:de\\s)?(\\d+)\\s?(minute|seconde|heure)": "\\1 \\2"
        },
        {
            "moins\\s(?:de\\s)?(\\d+)\\s?s": "\\1 seconde"
        },
        {
            "moins\\s(?:de\\s)?(\\d+)\\s?m": "\\1 minute"
        },
        {
            "moins\\s(?:de\\s)?(\\d+)\\s?h": "\\1 heure"
        },
        {
            "deux": "2"
        },
        {
            "trois": "3"
        },
        {
            "quatre": "4"
        },
        {
            "cinq": "5"
        },
        {
            "six": "6"
        },
        {
            "sept": "7"
        },
        {
            "huit": "8"
        },
        {
            "neuf": "9"
        },
        {
            "dix": "10"
        },
        {
            "onze": "11"
        },
        {
            "douze": "12"
        }
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "mzn",
    "date_order": "YMD",
    "january": [
        "ژانویه"
    ],
    "february": [
        "فوریه"
    ],
    "march": [
        "مارس"
    ],
    "april": [
        "آوریل"
    ],
    "may": [
        "مه"
    ],
    "june": [
        "ژوئن"
    ],
    "july": [
        "ژوئیه"
    ],
    "august": [
        "اوت"
    ],
    "september": [
        "سپتامبر"
    ],
    "october": [
        "اکتبر"
    ],
    "november": [
        "نوامبر"
    ],
    "december": [
        "دسامبر"
    ],
    "monday": [
        "mon"
    ],
    "tuesday": [
        "tue"
    ],
    "wednesday": [
        "wed"
    ],
    "thursday": [
        "thu"
    ],
    "friday": [
        "fri"
    ],
    "saturday": [
        "sat"
    ],
    "sunday": [
        "sun"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "سال"
    ],
    "month": [
        "ماه"
    ],
    "week": [
        "هفته"
    ],
    "day": [
        "روز"
    ],
    "hour": [
        "ساعِت",
        "ساعت"
    ],
    "minute": [
        "دقیقه",
        "دَقه"
    ],
    "second": [
        "ثانیه"
    ],
    "relative-type": {
        "1 year ago": [
            "پارسال"
        ],
        "0 year ago": [
            "امسال"
        ],
        "in 1 year": [
            "سال دیگه"
        ],
        "1 month ago": [
            "ماه قبل"
        ],
        "0 month ago": [
            "این ماه"
        ],
        "in 1 month": [
            "ماه ِبعد"
        ],
        "1 week ago": [
            "قبلی هفته"
        ],
        "0 week ago": [
            "این هفته"
        ],
        "in 1 week": [
            "بعدی هفته"
        ],
        "1 day ago": [
            "دیروز"
        ],
        "0 day ago": [
            "اَمروز"
        ],
        "in 1 day": [
            "فِردا"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) سال دله"
        ],
        "\\1 year ago": [
            "(\\d+) سال پیش"
        ],
        "in \\1 month": [
            "(\\d+) ماه دله"
        ],
        "\\1 month ago": [
            "(\\d+) ماه پیش"
        ],
        "in \\1 week": [
            "(\\d+) هفته دله"
        ],
        "\\1 week ago": [
            "(\\d+) هفته پیش"
        ],
        "in \\1 day": [
            "(\\d+) روز دله"
        ],
        "\\1 day ago": [
            "(\\d+) روز پیش"
        ],
        "in \\1 hour": [
            "(\\d+) ساعِت دله",
            "(\\d+) ساعت دله"
        ],
        "\\1 hour ago": [
            "(\\d+) ساعِت پیش",
            "(\\d+) ساعت پیش"
        ],
        "in \\1 minute": [
            "(\\d+) دقیقه دله",
            "(\\d+) دَقه دله"
        ],
        "\\1 minute ago": [
            "(\\d+) دَقه پیش"
        ],
        "in \\1 second": [
            "(\\d+) ثانیه دله"
        ],
        "\\1 second ago": [
            "(\\d+) ثانیه پیش"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "cgg",
    "date_order": "DMY",
    "january": [
        "okwokubanza",
        "kbz"
    ],
    "february": [
        "okwakabiri",
        "kbr"
    ],
    "march": [
        "okwakashatu",
        "kst"
    ],
    "april": [
        "okwakana",
        "kkn"
    ],
    "may": [
        "okwakataana",
        "ktn"
    ],
    "june": [
        "okwamukaaga",
        "kmk"
    ],
    "july": [
        "okwamushanju",
        "kms"
    ],
    "august": [
        "okwamunaana",
        "kmn"
    ],
    "september": [
        "okwamwenda",
        "kmw"
    ],
    "october": [
        "okwaikumi",
        "kkm"
    ],
    "november": [
        "okwaikumi na kumwe",
        "knk"
    ],
    "december": [
        "okwaikumi na ibiri",
        "knb"
    ],
    "monday": [
        "orwokubanza",
        "ork"
    ],
    "tuesday": [
        "orwakabiri",
        "okb"
    ],
    "wednesday": [
        "orwakashatu",
        "oks"
    ],
    "thursday": [
        "orwakana",
        "okn"
    ],
    "friday": [
        "orwakataano",
        "okt"
    ],
    "saturday": [
        "orwamukaaga",
        "omk"
    ],
    "sunday": [
        "sande",
        "san"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "omwaka"
    ],
    "month": [
        "omwezi"
    ],
    "week": [
        "esande"
    ],
    "day": [
        "eizooba"
    ],
    "hour": [
        "shaaha"
    ],
    "minute": [
        "edakiika"
    ],
    "second": [
        "obucweka/esekendi"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "nyomwabazyo"
        ],
        "0 day ago": [
            "erizooba"
        ],
        "in 1 day": [
            "nyenkyakare"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "dua",
    "date_order": "DMY",
    "january": [
        "dimɔ́di",
        "di"
    ],
    "february": [
        "ŋgɔndɛ",
        "ŋgɔn"
    ],
    "march": [
        "sɔŋɛ",
        "sɔŋ"
    ],
    "april": [
        "diɓáɓá",
        "diɓ"
    ],
    "may": [
        "emiasele",
        "emi"
    ],
    "june": [
        "esɔpɛsɔpɛ",
        "esɔ"
    ],
    "july": [
        "madiɓɛ́díɓɛ́",
        "mad"
    ],
    "august": [
        "diŋgindi",
        "diŋ"
    ],
    "september": [
        "nyɛtɛki",
        "nyɛt"
    ],
    "october": [
        "mayésɛ́",
        "may"
    ],
    "november": [
        "tiníní",
        "tin"
    ],
    "december": [
        "eláŋgɛ́",
        "elá"
    ],
    "monday": [
        "mɔ́sú",
        "mɔ́s"
    ],
    "tuesday": [
        "kwasú",
        "kwa"
    ],
    "wednesday": [
        "mukɔ́sú",
        "muk"
    ],
    "thursday": [
        "ŋgisú",
        "ŋgi"
    ],
    "friday": [
        "ɗónɛsú",
        "ɗón"
    ],
    "saturday": [
        "esaɓasú",
        "esa"
    ],
    "sunday": [
        "éti",
        "ét"
    ],
    "am": [
        "idiɓa"
    ],
    "pm": [
        "ebyámu"
    ],
    "year": [
        "mbú"
    ],
    "month": [
        "mɔ́di"
    ],
    "week": [
        "disama"
    ],
    "day": [
        "búnyá"
    ],
    "hour": [
        "ŋgandɛ"
    ],
    "minute": [
        "ndɔkɔ"
    ],
    "second": [
        "píndí"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "kíɛlɛ nítómb́í"
        ],
        "0 day ago": [
            "wɛ́ŋgɛ̄"
        ],
        "in 1 day": [
            "kíɛlɛ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "se",
    "date_order": "YMD",
    "january": [
        "ođđajagemánnu",
        "ođđj"
    ],
    "february": [
        "guovvamánnu",
        "guov"
    ],
    "march": [
        "njukčamánnu",
        "njuk"
    ],
    "april": [
        "cuoŋománnu",
        "cuo"
    ],
    "may": [
        "miessemánnu",
        "mies"
    ],
    "june": [
        "geassemánnu",
        "geas"
    ],
    "july": [
        "suoidnemánnu",
        "suoi"
    ],
    "august": [
        "borgemánnu",
        "borg"
    ],
    "september": [
        "čakčamánnu",
        "čakč"
    ],
    "october": [
        "golggotmánnu",
        "golg"
    ],
    "november": [
        "skábmamánnu",
        "skáb"
    ],
    "december": [
        "juovlamánnu",
        "juov"
    ],
    "monday": [
        "vuossárga",
        "vuos"
    ],
    "tuesday": [
        "maŋŋebárga",
        "maŋ"
    ],
    "wednesday": [
        "gaskavahkku",
        "gask"
    ],
    "thursday": [
        "duorasdat",
        "duor"
    ],
    "friday": [
        "bearjadat",
        "bear"
    ],
    "saturday": [
        "lávvardat",
        "láv"
    ],
    "sunday": [
        "sotnabeaivi",
        "sotn"
    ],
    "am": [
        "iđitbeaivi",
        "ib",
        "iđitbeaivet"
    ],
    "pm": [
        "eahketbeaivi",
        "eb",
        "eahketbeaivet"
    ],
    "year": [
        "jáhki"
    ],
    "month": [
        "mánnu"
    ],
    "week": [
        "váhkku"
    ],
    "day": [
        "beaivi"
    ],
    "hour": [
        "diibmu"
    ],
    "minute": [
        "minuhtta"
    ],
    "second": [
        "sekunda"
    ],
    "relative-type": {
        "1 year ago": [
            "last year"
        ],
        "0 year ago": [
            "this year"
        ],
        "in 1 year": [
            "next year"
        ],
        "1 month ago": [
            "last month"
        ],
        "0 month ago": [
            "this month"
        ],
        "in 1 month": [
            "next month"
        ],
        "1 week ago": [
            "last week"
        ],
        "0 week ago": [
            "this week"
        ],
        "in 1 week": [
            "next week"
        ],
        "1 day ago": [
            "ikte"
        ],
        "0 day ago": [
            "odne"
        ],
        "in 1 day": [
            "ihttin"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "(\\d+) jahki maŋŋilit",
            "(\\d+) jahkki maŋŋilit"
        ],
        "\\1 year ago": [
            "(\\d+) jahki árat",
            "(\\d+) jahkki árat"
        ],
        "in \\1 month": [
            "(\\d+) mánotbadji maŋŋilit"
        ],
        "\\1 month ago": [
            "(\\d+) mánotbadji árat"
        ],
        "in \\1 week": [
            "(\\d+) vahku maŋŋilit",
            "(\\d+) vahkku maŋŋilit"
        ],
        "\\1 week ago": [
            "(\\d+) vahku árat",
            "(\\d+) vahkku árat"
        ],
        "in \\1 day": [
            "(\\d+) jándor maŋŋilit",
            "(\\d+) jándora maŋŋilit"
        ],
        "\\1 day ago": [
            "(\\d+) jándor árat",
            "(\\d+) jándora árat"
        ],
        "in \\1 hour": [
            "(\\d+) diibmu maŋŋilit",
            "(\\d+) diibmur maŋŋilit"
        ],
        "\\1 hour ago": [
            "(\\d+) diibmu árat",
            "(\\d+) diibmur árat"
        ],
        "in \\1 minute": [
            "(\\d+) minuhta maŋŋilit",
            "(\\d+) minuhtta maŋŋilit"
        ],
        "\\1 minute ago": [
            "(\\d+) minuhta árat",
            "(\\d+) minuhtta árat"
        ],
        "in \\1 second": [
            "(\\d+) sekunda maŋŋilit",
            "(\\d+) sekundda maŋŋilit"
        ],
        "\\1 second ago": [
            "(\\d+) sekunda árat",
            "(\\d+) sekundda árat"
        ]
    },
    "locale_specific": {
        "se-FI": {
            "name": "se-FI",
            "monday": [
                "vuossárgga"
            ],
            "tuesday": [
                "maŋŋebárgga"
            ],
            "wednesday": [
                "gaskavahku"
            ],
            "thursday": [
                "duorastaga"
            ],
            "friday": [
                "bearjadaga"
            ],
            "saturday": [
                "lávvardaga"
            ],
            "year": [
                "jahki",
                "j"
            ],
            "week": [
                "vahkku"
            ],
            "relative-type": {
                "1 year ago": [
                    "mannan jagi"
                ],
                "0 year ago": [
                    "dán jagi"
                ],
                "in 1 year": [
                    "boahtte jagi"
                ]
            },
            "relative-type-regex": {
                "in \\1 year": [
                    "(\\d+) jagi siste"
                ],
                "\\1 year ago": [
                    "(\\d+) jagi árat"
                ]
            }
        },
        "se-SE": {
            "name": "se-SE"
        }
    },
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}



# -*- coding: utf-8 -*-
info = {
    "name": "ga",
    "date_order": "DMY",
    "january": [
        "eanáir",
        "ean"
    ],
    "february": [
        "feabhra",
        "feabh"
    ],
    "march": [
        "márta"
    ],
    "april": [
        "aibreán",
        "aib"
    ],
    "may": [
        "bealtaine",
        "beal"
    ],
    "june": [
        "meitheamh",
        "meith"
    ],
    "july": [
        "iúil"
    ],
    "august": [
        "lúnasa",
        "lún"
    ],
    "september": [
        "meán fómhair",
        "mfómh"
    ],
    "october": [
        "deireadh fómhair",
        "dfómh"
    ],
    "november": [
        "samhain",
        "samh"
    ],
    "december": [
        "nollaig",
        "noll"
    ],
    "monday": [
        "dé luain",
        "luan"
    ],
    "tuesday": [
        "dé máirt",
        "máirt"
    ],
    "wednesday": [
        "dé céadaoin",
        "céad"
    ],
    "thursday": [
        "déardaoin",
        "déar"
    ],
    "friday": [
        "dé haoine",
        "aoine"
    ],
    "saturday": [
        "dé sathairn",
        "sath"
    ],
    "sunday": [
        "dé domhnaigh",
        "domh"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "bliain",
        "bl"
    ],
    "month": [
        "mí"
    ],
    "week": [
        "seachtain",
        "scht"
    ],
    "day": [
        "lá"
    ],
    "hour": [
        "uair",
        "u"
    ],
    "minute": [
        "nóiméad",
        "nóim",
        "n"
    ],
    "second": [
        "soicind",
        "soic",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "anuraidh"
        ],
        "0 year ago": [
            "an bhliain seo",
            "an bhl seo"
        ],
        "in 1 year": [
            "an bhliain seo chugainn",
            "an bhl seo chugainn"
        ],
        "1 month ago": [
            "an mhí seo caite"
        ],
        "0 month ago": [
            "an mhí seo"
        ],
        "in 1 month": [
            "an mhí seo chugainn"
        ],
        "1 week ago": [
            "an tseachtain seo caite",
            "an tscht seo caite"
        ],
        "0 week ago": [
            "an tseachtain seo",
            "an tscht seo"
        ],
        "in 1 week": [
            "an tseachtain seo chugainn",
            "an tscht seo chugainn"
        ],
        "1 day ago": [
            "inné"
        ],
        "0 day ago": [
            "inniu"
        ],
        "in 1 day": [
            "amárach"
        ],
        "0 hour ago": [
            "an uair seo"
        ],
        "0 minute ago": [
            "an nóiméad seo"
        ],
        "0 second ago": [
            "anois"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "i gceann (\\d+) bhliain",
            "i gceann (\\d+) bliain",
            "i gceann (\\d+) bl"
        ],
        "\\1 year ago": [
            "(\\d+) bhliain ó shin",
            "(\\d+) bliain ó shin",
            "(\\d+) bhl ó shin",
            "(\\d+) bl ó shin"
        ],
        "in \\1 month": [
            "i gceann (\\d+) mhí",
            "i gceann (\\d+) mí"
        ],
        "\\1 month ago": [
            "(\\d+) mhí ó shin",
            "(\\d+) mí ó shin"
        ],
        "in \\1 week": [
            "i gceann (\\d+) seachtain",
            "i gceann (\\d+) scht"
        ],
        "\\1 week ago": [
            "(\\d+) seachtain ó shin",
            "(\\d+) scht ó shin"
        ],
        "in \\1 day": [
            "i gceann (\\d+) lá"
        ],
        "\\1 day ago": [
            "(\\d+) lá ó shin"
        ],
        "in \\1 hour": [
            "i gceann (\\d+) uair an chloig",
            "i gceann (\\d+) uair"
        ],
        "\\1 hour ago": [
            "(\\d+) uair an chloig ó shin",
            "(\\d+) uair ó shin"
        ],
        "in \\1 minute": [
            "i gceann (\\d+) nóiméad",
            "i gceann (\\d+) nóim"
        ],
        "\\1 minute ago": [
            "(\\d+) nóiméad ó shin",
            "(\\d+) nóim ó shin"
        ],
        "in \\1 second": [
            "i gceann (\\d+) soicind",
            "i gceann (\\d+) soic"
        ],
        "\\1 second ago": [
            "(\\d+) soicind ó shin",
            "(\\d+) soic ó shin"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}
